@@ -1,7 +1,7 @@
 #' Retrieve the taxonomic hierarchy for a given taxon ID.
 #'
 #' @export
-#' @param x Vector of taxa names (character) or IDs (character or numeric)
+#' @param sci_id Vector of taxa names (character) or IDs (character or numeric)
 #' to query. For `db = "eol"`, EOL expects you to pass it a taxon id, called
 #' `eolid` in the output of [get_eolid()]. 
 #' @param db character; database to query. either `ncbi`, `itis`, `eol`,
@@ -9,7 +9,7 @@
 #' Note that each taxonomic data source has, their own identifiers, so that
 #' if you provide the wrong `db` value for the identifier you could get a
 #' result, but it will likely be wrong (not what you were expecting). If using
-#' ncbi, eol, and/or tropicos, we recommend getting an API key; see
+#' ncbi, and/or tropicos, we recommend getting an API key; see
 #' [taxize-authentication]
 #' @param id character; identifiers, returned by [get_tsn()], [get_uid()],
 #' [get_eolid()], [get_tpsid()], [get_gbifid()], [get_tolid()],
@@ -28,6 +28,11 @@
 #' @param rows (numeric) Any number from 1 to infinity. If the default NA,
 #' all rows are considered. Note that this parameter is ignored if you pass
 #' in a taxonomic id instead of a name of class character.
+#' @param batch_size (numeric) For NCBI queries, specify the number of IDs to
+#'   lookup for each query.
+#' @param max_tries (numeric) For NCBI queries, the number of times a particular
+#'   query will be attempted, assuming the first does not work.
+#' @param x Deprecated, see `sci_id`
 #'
 #' @return A named list of data.frames with the taxonomic classification of
 #'    every supplied taxa.
@@ -61,6 +66,10 @@
 #' not an appropriate error; it's probably that that ID does not exist 
 #' in their database, but we can't know for sure. Isn't that fun?
 #' 
+#' @section NCBI Rate limits:
+#' In case you run into NCBI errors due to your rate limit being exceeded, see
+#' [taxize_options()], where you can set `ncbi_sleep`.
+#' 
 #' @section HTTP version for NCBI requests:
 #' We hard code `http_version = 2L` to use HTTP/1.1 in HTTP requests to
 #' the Entrez API. See `curl::curl_symbols('CURL_HTTP_VERSION')` 
@@ -75,8 +84,8 @@
 #' classification('Helianthus annuus', db = 'pow')
 #' classification('Helianthus', db = 'pow')
 #' classification('Asteraceae', db = 'pow')
-#' classification("ELEMENT_GLOBAL.2.134717", db = 'natserv')
-#' classification(c(2704179, 2441176), db = 'gbif')
+#' classification("134717", db = 'natserv')
+#' classification(c(2704179, 6162875, 8286319, 2441175, 731), db = 'gbif')
 #' classification(25509881, db = 'tropicos')
 #' classification("NBNSYS0000004786", db = 'nbn')
 #' classification(as.nbnid("NBNSYS0000004786"), db = 'nbn')
@@ -130,7 +139,7 @@
 #' classification(get_gbifid(c("Poa annua", "Bison bison")))
 #'
 #' # Pass many ids from class "ids"
-#' (out <- get_ids(names="Puma concolor", db = c('ncbi','gbif')))
+#' (out <- get_ids("Puma concolor", db = c('ncbi','gbif')))
 #' (cl <- classification(out))
 #'
 #' # Bind width-wise from class classification_ids
@@ -140,7 +149,7 @@
 #' rbind(cl)
 #'
 #' # Many names to get_ids
-#' (out <- get_ids(names=c("Puma concolor","Accipiter striatus"),
+#' (out <- get_ids(c("Puma concolor","Accipiter striatus"),
 #'   db = c('ncbi','itis')))
 #' (cl <- classification(out))
 #' rbind(cl)
@@ -185,6 +194,25 @@
 #' classification('Poa annua', db = 'tropicos', rows=1:4)
 #' classification('Poa annua', db = 'tropicos', rows=1)
 #' classification('Poa annua', db = 'tropicos', rows=6)
+#' 
+#' # Queries of many IDs are processed in batches for NCBI
+#' ids <- c("13083", "2650392", "1547764", "230054", "353934", "656984", 
+#' "271789", "126272", "184644", "73213", "662816", "1161803", "1239353", 
+#' "59420", "665675", "866969", "1091219", "1431218", "1471898", 
+#' "864321", "251768", "2486276", "2068772", "1825808", "2006532", 
+#' "128287", "1195738", "1084683", "1886461", "508296", "377247", 
+#' "1489665", "329325", "219243", "1176946", "339893", "197933", 
+#' "174510", "1704048", "212897", "154842", "1239280", "260135", 
+#' "405735", "1566412", "2083462", "651348", "983204", "165380", 
+#' "2338856", "2068760", "167262", "34229", "1213340", "478939", 
+#' "1933585", "49951", "1277794", "1671089", "1502538", "362355", 
+#' "746473", "242879", "158219", "313664", "2093188", "1541232", 
+#' "584742", "1331091", "147639", "284492", "75642", "1412882", 
+#' "391782", "1406855", "434506", "2053357", "217315", "1444328", 
+#' "329249", "2294004", "84942", "324458", "538247", "69452", "49170", 
+#' "1993845", "261646", "127633", "228146", "1420004", "1629772", 
+#' "577055", "697062", "231660", "648380", "554953", "746496", "2602969")
+#' result <- classification(ids, db = 'ncbi')
 #' }
 #'
 #' @examples \dontrun{
@@ -197,68 +225,70 @@ classification <- function(...){
 
 #' @export
 #' @rdname classification
-classification.default <- function(x, db = NULL, callopts = list(),
-                                   return_id = TRUE, rows = NA, ...) {
+classification.default <- function(sci_id, db = NULL, callopts = list(),
+                                   return_id = TRUE, rows = NA, x = NULL, ...) {
   nstop(db)
+  pchk(x, "sci_id")
   switch(
     db,
     itis = {
-      id <- process_ids(x, db, get_tsn, rows = rows, ...)
-      stats::setNames(classification(id, return_id = return_id, ...), x)
+      id <- process_ids(sci_id, db, get_tsn, rows = rows, ...)
+      stats::setNames(classification(id, return_id = return_id, ...), sci_id)
     },
     ncbi = {
-      id <- process_ids(x, db, get_uid, rows = rows, ...)
+      id <- process_ids(sci_id, db, get_uid, rows = rows)
       stats::setNames(classification(id, callopts = callopts,
-        return_id = return_id, ...), x)
+        return_id = return_id), sci_id)
     },
     eol = {
-      id <- process_ids(x, db, get_eolid, rows = rows, ...)
+      id <- process_ids(sci_id, db, get_eolid, rows = rows, ...)
       stats::setNames(classification(id, callopts = callopts,
-        return_id = return_id, ...), x)
+        return_id = return_id, ...), sci_id)
     },
     tropicos = {
-      id <- process_ids(x, db, get_tpsid, rows = rows, ...)
+      id <- process_ids(sci_id, db, get_tpsid, rows = rows, ...)
       stats::setNames(classification(id, callopts = callopts,
-        return_id = return_id, ...), x)
+        return_id = return_id, ...), sci_id)
     },
     gbif = {
-      id <- process_ids(x, db, get_gbifid, rows = rows, ...)
+      id <- process_ids(sci_id, db, get_gbifid, rows = rows, ...)
       stats::setNames(classification(id, callopts = callopts,
-        return_id = return_id, ...), x)
+        return_id = return_id, ...), sci_id)
     },
     nbn = {
-      id <- process_ids(x, db, get_nbnid, rows = rows, ...)
+      id <- process_ids(sci_id, db, get_nbnid, rows = rows, ...)
       stats::setNames(classification(id, callopts = callopts,
-        return_id = return_id, ...), x)
+        return_id = return_id, ...), sci_id)
     },
     tol = {
-      id <- process_ids(x, db, get_tolid, rows = rows, ...)
+      id <- process_ids(sci_id, db, get_tolid, rows = rows, ...)
       stats::setNames(classification(id, callopts = callopts,
-        return_id = return_id, ...), x)
+        return_id = return_id, ...), sci_id)
     },
     worms = {
-      id <- process_ids(x, db, get_wormsid, rows = rows, ...)
+      id <- process_ids(sci_id, db, get_wormsid, rows = rows, ...)
       stats::setNames(classification(id, callopts = callopts,
-        return_id = return_id, ...), x)
+        return_id = return_id, ...), sci_id)
     },
     natserv = {
-      id <- process_ids(x, db, get_natservid, rows = rows, ...)
+      id <- process_ids(sci_id, db, get_natservid, rows = rows, ...)
       stats::setNames(classification(id, callopts = callopts,
-        return_id = return_id, ...), x)
+        return_id = return_id, ...), sci_id)
     },
     bold = {
-      id <- process_ids(x, db, get_boldid, rows = rows, ...)
+      id <- process_ids(sci_id, db, get_boldid, rows = rows, ...)
       stats::setNames(classification(id, callopts = callopts,
-        return_id = return_id, ...), x)
+        return_id = return_id, ...), sci_id)
     },
     wiki = {
-      id <- process_ids(x, db, get_wiki, rows = rows, ...)
+      id <- process_ids(sci_id, db, get_wiki, rows = rows, ...)
       stats::setNames(classification(id, callopts = callopts,
-        return_id = return_id, ...), x)
+        return_id = return_id, ...), sci_id)
     },
     pow = {
-      id <- process_ids(x, db, get_pow, rows = rows, ...)
-      stats::setNames(classification(id, callopts = callopts, return_id = return_id, ...), x)
+      id <- process_ids(sci_id, db, get_pow, rows = rows, ...)
+      stats::setNames(classification(id, callopts = callopts,
+        return_id = return_id, ...), sci_id)
     },
     stop("the provided db value was not recognised", call. = FALSE)
   )
@@ -269,7 +299,6 @@ process_ids <- function(input, db, fxn, ...){
   if (
     inherits(g, "numeric") || # all others
     is.character(input) && all(grepl("N[HB]", input)) || # NBN
-    is.character(input) && all(grepl("ELEMENT_GLOBAL", input)) || # Natserv
     is.character(input) && all(grepl("urn:lsid", input)) # POW
   ) {
     as_fxn <- switch(db,
@@ -320,49 +349,83 @@ classification.tsn <- function(id, return_id = TRUE, ...) {
 
 #' @export
 #' @rdname classification
-classification.uid <- function(id, callopts = list(), return_id = TRUE, ...) {
+classification.uid <- function(id, callopts = list(), return_id = TRUE,
+  batch_size = 50, max_tries = 3, ...) {
+
   warn_db(list(...), "ncbi")
-  fun <- function(x, callopts){
+  fun <- function(x, callopts) {
     key <- getkey(NULL, service="entrez")
-    # return NA if NA is supplied
-    if (is.na(x)) {
-      out <- NA
-    } else {
-      query <- tc(list(db = "taxonomy", ID = x, api_key = key))
+    
+    query_ncbi <- function(ids) {
+      query <- tc(list(db = "taxonomy", ID = paste0(ids, collapse = ','),
+        api_key = key))
       cli <- crul::HttpClient$new(url = ncbi_base(),
         opts = c(http_version = 2L, callopts))
-      res <- cli$get("entrez/eutils/efetch.fcgi", query = query)
-      res$raise_for_status()
-      tt <- res$parse("UTF-8")
-      ttp <- xml2::read_xml(tt)
-      out <- data.frame(
-        name = xml_text_all(ttp,
-          "//TaxaSet/Taxon/LineageEx/Taxon/ScientificName"),
-        rank = xml_text_all(ttp, "//TaxaSet/Taxon/LineageEx/Taxon/Rank"),
-        id = xml_text_all(ttp, "//TaxaSet/Taxon/LineageEx/Taxon/TaxId"),
-        stringsAsFactors = FALSE)
-      parent_id <- xml_text_all(ttp, "//TaxaSet/Taxon/ParentTaxId") %||% ""
-      # Is not directly below root and no lineage info
-      if (NROW(out) == 0 && parent_id != "1") {
-        out <- NA
-      } else {
-        out <- rbind(out,
-          data.frame(
-            name = xml_text_all(ttp, "//TaxaSet/Taxon/ScientificName"),
-            rank = xml_text_all(ttp, "//TaxaSet/Taxon/Rank"),
-            id = xml_text_all(ttp, "//TaxaSet/Taxon/TaxId"),
-            stringsAsFactors = FALSE))
-        # Optionally return tsn of lineage
-        if (!return_id) out <- out[, c('name', 'rank')]
-        out$rank <- tolower(out$rank)
-        return(out)
+      success <- FALSE
+      tries <- 1
+      while (success == FALSE && tries <= max_tries) {
+        res <- cli$get("entrez/eutils/efetch.fcgi", query = query)
+        res$raise_for_status()
+        tt <- res$parse("UTF-8")
+        ttp <- xml2::read_xml(tt)
+        out <- lapply(xml2::xml_find_all(ttp, '//TaxaSet/Taxon'),
+          function(tax_node) {
+          lin <- data.frame(
+            name = xml_text_all(tax_node,
+              ".//LineageEx/Taxon/ScientificName"),
+            rank = xml_text_all(tax_node, ".//LineageEx/Taxon/Rank"),
+            id = xml_text_all(tax_node, ".//LineageEx/Taxon/TaxId"),
+            stringsAsFactors = FALSE)
+          targ_tax <- data.frame(
+            name = xml_text_all(tax_node, "./ScientificName"),
+            rank = xml_text_all(tax_node, "./Rank"),
+            id = xml_text_all(tax_node, "./TaxId"),
+            stringsAsFactors = FALSE)
+          rbind(lin, targ_tax)
+        })
+        # Is not directly below root and no lineage info
+        parent_id <- xml_text_all(ttp, "//TaxaSet/Taxon/ParentTaxId") %||% ""
+        out[vapply(out, NROW, numeric(1)) == 0 & parent_id != "1"] <- NA
+        # Add NA where the taxon ID was not found
+        names(out) <- xml_text(xml2::xml_find_all(ttp,
+          '//TaxaSet/Taxon/TaxId'))
+        success <- ! grepl(tt, pattern = 'error', ignore.case = TRUE)
+        tries <- tries + 1
+        # NCBI limits requests to three per second without key or 10 per
+        # second with key
+        ncbi_rate_limit_pause(key)
+        # Wait longer if query failed
+        if (success == FALSE) {
+          Sys.sleep(1)
+        }
       }
+      # Return NA if cannot get information
+      if (!success) {
+        out <- rep(list(NA), length(ids))
+        warning(call. = FALSE, 'Giving up on query after ',
+          max_tries, ' tries. NAs will be returned.')
+      }
+      return(out)
     }
-    # NCBI limits requests to three per second
-    if (is.null(key)) Sys.sleep(0.34)
+    # return NA if NA is supplied
+    out <- rep(list(NA), length(x))
+    out[! is.na(x)] <- query_ncbi(x[! is.na(x)])
+    # Optionally return taxon id of lineage taxa
+    if (!return_id) {
+      out[! is.na(out)] <- lapply(out[! is.na(out)],
+        function(o) o[, c('name', 'rank')])
+    }
+    # Return ranks in all lower case
+    out[! is.na(out)] <- lapply(out[! is.na(out)], function(o) {
+      o$rank <- tolower(o$rank)
+      return(o)
+    })
     return(out)
   }
-  out <- lapply(id, fun, callopts = callopts)
+  id <- as.character(id) # force to character
+  id_chunks <- split(id, ceiling(seq_along(id)/batch_size))
+  out <- lapply(id_chunks, fun, callopts = callopts)
+  out <- unlist(out, recursive = FALSE)
   names(out) <- id
   structure(out, class = 'classification', db = 'ncbi')
 }
@@ -376,7 +439,6 @@ classification.eolid <- function(id, callopts = list(), return_id = TRUE, ...) {
     if (is.na(x)) {
       out <- NA
     } else {
-      key <- getkey(NULL, "EOL_KEY")
       args <- tc(list(common_names = common_names, synonyms = synonyms))
       cli <- crul::HttpClient$new(url = 'https://eol.org', opts = callopts)
       tt <- cli$get(file.path('api/hierarchy_entries/1.0', paste0(x, ".json")),
@@ -455,11 +517,26 @@ classification.gbifid <- function(id, callopts = list(),
         NA
       } else {
         cls = c('kingdom','phylum','class', 'order','family','genus','species')
-        nms <- nmdlst2df(out[names(out) %in% cls])
-        keys <- unname(unlist(out[names(out) %in% paste0(cls, "Key")]))
-        df <- data.frame(name = nms$V1, rank = nms$.id, id = keys,
-          stringsAsFactors = FALSE)
+        df1 <- stats::setNames(nmdlst2df(out[names(out) %in% cls]),
+          c("rank", "name"))
+        df2 <- stats::setNames(
+          nmdlst2df(out[names(out) %in% paste0(cls, "Key")]),
+          c(".id", "id"))
+        df2$rank <- sub("Key", "", df2$.id)
+        df2$.id <- NULL
+        df <- merge(df1, df2, by = "rank")
         df$rank <- tolower(df$rank)
+        # sort to make sure ranks are in correct descending order
+        df <- df[order(vapply(df$rank, which_rank, 1)), ]
+        # column order
+        df <- data.frame(name = df$name, rank = df$rank, id = df$id,
+          stringsAsFactors = FALSE)
+        # check if target taxon is sub-specific
+        if (which_rank(tolower(out$rank)) > 37) {
+          df <- rbind(df,
+            c(out$canonicalName, tolower(out$rank), out$key))
+        }
+        df$id <- as.integer(df$id)
         # Optionally return id of lineage
         if (!return_id) df[, c('name', 'rank')] else df
       }
@@ -573,25 +650,33 @@ classification.natservid <- function(id, callopts = list(),
     if (is.na(x)) {
       out <- NA
     } else {
-      out <- tryCatch(natserv::ns_data(x), error = function(e) e)
+      out <- tryCatch(natserv::ns_id(paste0("ELEMENT_GLOBAL.2.", x)), error = function(e) e)
+      # out <- tryCatch(natserv::ns_data(x), error = function(e) e)
       if (inherits(out, "error")) {
         NA
       } else {
-        tmp <- out[[1]]$classification
-        if (is.null(tmp)) return(NA)
-        tmp <- tmp$taxonomy$formalTaxonomy
-        if (is.null(tmp)) return(NA)
-        tmp <- tmp[names(tmp) %in% c('kingdom', 'phylum',
-          'class', 'order', 'family', 'genus')]
-        df <- data.frame(scientificname = unname(unlist(tmp)),
-          rank = names(tmp), stringsAsFactors = FALSE)
-        rks <- c('kingdom', 'phylum', 'class', 'order',
-          'family', 'genus', 'species')
-        targ_taxon <- c(
-          out[[1]]$classification$names$scientificName$unformattedName[[1]],
-          rks[which(df$rank[length(df$rank)] == rks) + 1]
-        )
-        df <- rbind(df, targ_taxon)
+        zz <- c("kingdom", "phylum", "taxclass", "taxorder", "family", "genus")
+        if (is.null(out$speciesGlobal)) return(NA)
+        res <- tc(out$speciesGlobal[zz])
+        if (length(res) == 0) return(NA)
+        df <- data.frame(scientificname = unname(unlist(res)),
+          rank = gsub("tax", "", names(res)), stringsAsFactors = FALSE)
+        df <- rbind(df, c(out$scientificName, "species"))
+        # tmp <- out[[1]]$classification
+        # if (is.null(tmp)) return(NA)
+        # tmp <- tmp$taxonomy$formalTaxonomy
+        # if (is.null(tmp)) return(NA)
+        # tmp <- tmp[names(tmp) %in% c('kingdom', 'phylum',
+        #   'class', 'order', 'family', 'genus')]
+        # df <- data.frame(scientificname = unname(unlist(tmp)),
+        #   rank = names(tmp), stringsAsFactors = FALSE)
+        # rks <- c('kingdom', 'phylum', 'class', 'order',
+        #   'family', 'genus', 'species')
+        # targ_taxon <- c(
+        #   out[[1]]$classification$names$scientificName$unformattedName[[1]],
+        #   rks[which(df$rank[length(df$rank)] == rks) + 1]
+        # )
+        # df <- rbind(df, targ_taxon)
         return(df)
       }
     }
