@@ -141,12 +141,14 @@ get_wormsid <- function(sci_com, searchtype = "scientific", marine_only = TRUE,
     if (!searchtype %in% c("scientific", "common")) {
       stop("'searchtype' must be one of 'scientific' or 'common'", call. = FALSE)
     }
+    # NOTE: space replacement needed for curl problem (issue #888)
+    query <- gsub(sci_com[i], pattern = ' ', replacement = '+', fixed = TRUE)
     wmdf <- switch(
       searchtype,
-      scientific = worms_worker(sci_com[i], worrms::wm_records_name, rows,
-        marine_only, fuzzy %||% TRUE, ...),
-      common = worms_worker(sci_com[i], worrms::wm_records_common, rows,
-        marine_only, fuzzy %||% FALSE, ...)
+      scientific = worms_worker(query, worrms::wm_records_name, rows,
+                                marine_only, fuzzy %||% TRUE, ...),
+      common = worms_worker(query, worrms::wm_records_common, rows,
+                            marine_only, fuzzy %||% FALSE, ...)
     )
     mm <- NROW(wmdf) > 1
 
