@@ -25,7 +25,6 @@
 #' \tabular{llc}{
 #' API \tab prefix \tab SOAP? \cr
 #' Encyclopedia of Life (EOL)  \tab eol \tab FALSE \cr
-#' Taxonomic Name Resolution Service \tab tnrs \tab FALSE \cr
 #' Integrated Taxonomic Information Service (ITIS)  \tab itis \tab FALSE \cr
 #' Global Names Resolver (from EOL/GBIF) \tab gnr \tab FALSE \cr
 #' Global Names Index (from EOL/GBIF) \tab gni \tab FALSE \cr
@@ -50,7 +49,7 @@
 #'
 #' If the source above has a `TRUE` in the `SOAP?` column, it is not available
 #' in this package. They are available from a different package called **taxizesoap**.
-#' See the GitHub repo for how to install <https://github.com/ropensci/taxizesoap>
+#' See the GitHub repo for how to install https://github.com/ropensci/taxizesoap
 #' 
 #' @section Catalogue of Life (COL):
 #' COL introduced rate limiting recently in 2019 - which has made the API
@@ -73,10 +72,11 @@
 #' @importFrom R6 R6Class
 #' @importFrom crayon style
 #' @importFrom cli symbol cat_line rule
+#' @importFrom conditionz ConditionKeeper
 #' @name taxize-package
 #' @aliases taxize
 #' @docType package
-#' @author Scott Chamberlain \email{myrmecocystus@@gmail.com}
+#' @author Scott Chamberlain 
 #' @author Eduard Szoecs \email{eduardszoecs@@gmail.com}
 #' @author Zachary Foster \email{zacharyfoster1989@@gmail.com}
 #' @author Carl Boettiger \email{cboettig@@gmail.com}
@@ -89,7 +89,7 @@ NULL
 
 #' Lookup-table for IDs of taxonomic ranks
 #'
-#' data.frame of 43 rows, with 2 columns:
+#' data.frame of 46 rows, with 2 columns:
 #' * rankid - a numeric rank id, consecutive
 #' * ranks - a comma separated vector of names that are considered
 #'  equal to one another within the row
@@ -101,12 +101,27 @@ NULL
 #' sources \pkg{taxize} that we don't have in `rank_ref` dataset.
 #'
 #' Let us know if you disagree with the ordering of ranks.
+#' 
+#' Note that `rankid` 280 are essentially "genetic variants"; placed just above
+#' 'unspecified' to denote they're not without rank, but they're not
+#' really taxonomic ranks either. As far as I know there's no way 
+#' to delineate among these "genetic variant" types.
 #'
 #' @name rank_ref
 #' @docType data
 #' @keywords data
 NULL
 
+#' Lookup-table for IDs of taxonomic ranks (WoRMS)
+#'
+#' Same as `rank_ref` but specifically for WoRMS, where section/subsection
+#' ranks are put between family/order rather than between species/genus.
+#'
+#' @name rank_ref_zoo
+#' @docType data
+#' @keywords data
+NULL
+
 #' Lookup-table for family, genus, and species names for ThePlantList
 #'
 #' These names are from http://www.theplantlist.org, and are from
@@ -120,7 +135,7 @@ NULL
 #'   * `genus` genus name
 #'   * `species` specific epithet name
 #' 
-#' @source <http://www.theplantlist.org>
+#' @source http://www.theplantlist.org
 #' @name theplantlist
 #' @docType data
 #' @keywords data
@@ -131,16 +146,25 @@ NULL
 #' Family names and their replacements from the Angiosperm Phylogeny
 #' Website system of flowering plant classification.
 #'
-#' This dataset is from Version 13, incorporated on 2015-04-29.
+#' This dataset is from Version 14, incorporated on 2020-06-03, 
+#' generated using [apgFamilies()]
+#' 
+#' (update script in inst/ignore/apg_script.R)
 #'
-#' @format A data frame with 1597 rows and 4 variables:
+#' @format A data frame with 1705 rows and 6 variables:
 #' 
-#'   * `original` original data record from APG website
-#'   * `this` Order name
-#'   * `that` Replacement order name
-#'   * `order` Order name
+#' * `family`: family name
+#' * `synonym`: if `accepted=FALSE`, this is the accepted name;
+#' if `accepted=TRUE`, this is `NA`, and the name in `family` is accepted
+#' * `order`: order name for the family
+#' * `accepted`: logical, if name in `family` column is accepted or not
+#' * `original`: original data record from APG website, mapping
+#' name in `family` column to a new name, if there is one
+#' * `accepted_name`: accepted name. accepted names, combining those that
+#' are accepted from `family` column, with the new name from `synonym`
+#' if applicable
 #' 
-#' @source <http://www.mobot.org/MOBOT/research/APweb/>
+#' @source http://www.mobot.org/MOBOT/research/APweb/
 #' @name apg_families
 #' @docType data
 #' @keywords data
@@ -151,15 +175,24 @@ NULL
 #' Order names and their replacements from the Angiosperm Phylogeny
 #' Website system of flowering plant classification.
 #'
-#' This dataset is from Version 13, incorporated on 2015-04-29.
+#' This dataset is from Version 14, incorporated on 2020-06-03, 
+#' generated using [apgOrders()]
+#' 
+#' (update script in inst/ignore/apg_script.R)
 #'
-#' @format A data frame with 494 rows and 3 variables:
+#' @format A data frame with 576 rows and 5 variables:
 #' 
-#'   * `original` original data record from APG website
-#'   * `this` Order name
-#'   * `that` Replacement order name
+#' * `order`: order name
+#' * `synonym`: if `accepted=FALSE`, this is the accepted name;
+#' if `accepted=TRUE`, this is `NA`, and the name in `order` is accepted
+#' * `accepted`: logical, if name in `order` column is accepted or not
+#' * `original`: original data record from APG website, mapping
+#' name in `order` column to a new name, if there is one
+#' * `accepted_name`: accepted name. accepted names, combining those that
+#' are accepted from `order` column, with the new name from `synonym`
+#' if applicable
 #' 
-#' @source <http://www.mobot.org/MOBOT/research/APweb/>
+#' @source http://www.mobot.org/MOBOT/research/APweb/
 #' @name apg_orders
 #' @docType data
 #' @keywords data
@@ -200,7 +233,7 @@ NULL
 #' return rank names - with this dataset we can fill
 #' in rank information as long as rank ids are returned
 #'
-#' @format A data frame with 494 rows and 3 variables:
+#' @format A data frame with 216 rows and 2 variables:
 #'
 #'   * `id`: rank id
 #'   * `rank`: rank name
@@ -219,8 +252,10 @@ NULL
 #' `classification.colid`, `downstream.colid`, `id2name.colid`,
 #' `lowest_common.colid`, `synonyms.colid`, `upstream.colid`
 #' * `col_classification()`: See`classification()`
-#' * `eol_hierarchy()`: See`classification()`
 #' * `tp_classification()`: See`classification()`
+#' * `eol_hierarchy()`: See`classification()`
+#' * [eol_invasive()]: See `eol` in the \pkg{originr} package.
+#' * [use_eol()]: EOL no longer requires an API key
 #' * [tpl_search()]: Use the \pkg{Taxonstand} functions `TPL` or `TPLck` directly.
 #' * [get_seqs()]: This function changed name to`ncbi_getbyname()`()].
 #' * [get_genes()]: This function changed name to`ncbi_getbyid()`()].
@@ -228,7 +263,6 @@ NULL
 #' * [ncbi_getbyname()]: See `ncbi_byname` in the \pkg{traits} package.
 #' * [ncbi_getbyid()]: See `ncbi_byid` in the \pkg{traits} package.
 #' * [ncbi_search()]: See `ncbi_searcher` in the \pkg{traits} package.
-#' * [eol_invasive()]: See `eol` in the \pkg{originr} package.
 #' * [gisd_isinvasive()]: See `gisd` in the \pkg{originr} package.
 #' * [ubio_classification()]:  The uBio web services was down for quite a while, is
 #'  now (as of 2016-05-09) back up, but we don't trust that it will stay up and available.
@@ -250,6 +284,8 @@ NULL
 #'  `phylomatic_names` in the package \pkg{brranching}
 #' * [iucn_summary_id()]: This function is defunct. Use [iucn_summary()]
 #' * [eubon()]: This function is defunct. Use [eubon_search()]
+#' * [tnrs()]: This function is defunct. Was too unreliable
+#' * [tnrs_sources()]: This function is defunct. Was too unreliable
 #'
 #' @name taxize-defunct
 #' @aliases defunct
