@@ -36,7 +36,7 @@ test_that("passing in an id works", {
 test_that("queries with no results fail well", {
   skip_on_cran() # uses secrets
   vcr::use_cassette("children_no_results", {
-    aa <- children(x = "Saurauia", db = "itis", verbose = FALSE)
+    aa <- children("Saurauia", db = "itis", verbose = FALSE)
   })
   expect_equal(NROW(aa[[1]]), 0)
 })
@@ -113,9 +113,9 @@ test_that("children doesn't remove ambiguous taxa", {
   skip_on_cran()
   vcr::use_cassette("children_ambiguous_ncbi", {
     # 28901 = "Salmonella enterica" - DOES NOT remove "subsp."
-    subsp <- children(28901, db = "ncbi")
+    subsp <- children('28901', db = "ncbi")
     # 2508041 = "unclassified Helianthus" - DOES NOT remove "sp."
-    sp <- children(2508041, db = "ncbi")
+    sp <- children('2508041', db = "ncbi")
   })
 
   expect_is(subsp, "children")
@@ -135,3 +135,36 @@ test_that("warn on mismatch 'db'", {
         get_uid("Chironomus riparius", messages = FALSE), db = "itis"))
   })
 })
+
+test_that("works with source bold", {
+  skip_on_cran()
+  vcr::use_cassette("children_bold", {
+    x_id <- children("88899", db = "bold", messages = FALSE)
+    x_from_get <- children(get_boldid("Momotus", messages = FALSE))
+  })
+
+  expect_named(x_id, "88899")
+  expect_named(x_from_get, 'species')
+
+  expect_is(x_id, "children")
+  expect_is(x_id[[1]], "data.frame")
+  expect_is(x_id[[1]]$name, "character")
+  expect_match(x_id[[1]]$name, "Momotus")
+
+  expect_is(x_from_get, "children")
+  expect_is(x_from_get[[1]], "data.frame")
+  expect_is(x_from_get[[1]]$name, "character")
+  expect_match(x_from_get[[1]]$name, "Momotus")
+})
+
+test_that("works with worms, passing through marine_only", {
+  skip_on_cran()
+  vcr::use_cassette("children_worms_marine_only", {
+    a <- children("1837", db = "worms")
+    b <- children("1837", db = "worms", marine_only = FALSE)
+  })
+
+  expect_is(a, "children")
+  expect_is(b, 'children')
+  expect_gt(NROW(b[[1]]), NROW(a[[1]]))
+})
